References
==========
.. automodule:: pykeen.models.unimodal
.. automodule:: pykeen.models.multimodal

.. [ali2020a] Ali, M., *et al.* (2020). `Bringing Light Into the Dark: A Large-scale Evaluation of Knowledge
   Graph Embedding Models Under a Unified Framework <http://arxiv.org/abs/2006.13365>`_. *arXiv*, 2006.13365.

.. [safavi2020] Safavi, T. & Koutra, D. (2020). `CoDEx: A Comprehensive Knowledge Graph
   Completion Benchmark <http://arxiv.org/abs/2009.07810>`_.  *arXiv*, 2009.07810.

.. [shi2017b] Shi, B., & Weninger, T. (2017). `Open-World Knowledge Graph Completion
   <https://arxiv.org/abs/1711.03438>`_. *arXiv*, 1957–1964.

.. [santos2020] Santos, A., *et al* (2020). `Clinical Knowledge Graph Integrates Proteomics Data into Clinical
   Decision-Making <https://doi.org/10.1101/2020.05.09.084897>`_. *bioRxiv*, 2020.05.09.084897.

.. [speer2017] Robyn Speer, Joshua Chin, and Catherine Havasi. (2017)
   `ConceptNet 5.5: An Open Multilingual Graph of General Knowledge <https://arxiv.org/abs/1612.03975>`_.
   *In proceedings of AAAI 31*.

.. [breit2020] Breit, A., *et al* (2020). `OpenBioLink: A benchmarking framework for large-scale biomedical link
   prediction <https://doi.org/10.1093/bioinformatics/btaa274>`_, *Bioinformatics*

.. [ilievski2020] Ilievski, F., Szekely, P., & Zhang, B. (2020). `CSKG: The CommonSense Knowledge
   Graph <http://arxiv.org/abs/2012.11490>`_. *arxiv*, 2012.11490.

.. [himmelstein2017] Himmelstein, D. S., *et al* (2017). `Systematic integration of biomedical knowledge
   prioritizes drugs for repurposing <https://doi.org/10.7554/eLife.26726>`_. ELife, 6.

.. [xu2019] Xu, L (2019) `A Comparison of Learned and Engineered Features in Network-Based Drug Repositioning
   <https://github.com/lingling93/master_thesis_drugrelink>`_. Master's Thesis.

.. [santurkar2018] Santurkar, S., *et al*. (2018). `How does batch normalization help optimization?
   <https://arxiv.org/abs/1805.11604>`_. Advances in Neural Information Processing Systems.

.. [chao2020] Chao, L., He, J., Wang, T., & Chu, W. (2020). `PairRE: Knowledge Graph Embeddings
   via Paired Relation Vectors <http://arxiv.org/abs/2011.03798>`_.

.. [ding2018] Ding, B., Wang, Q., Wang, B., & Guo, L. (2018). `Improving Knowledge Graph Embedding Using Simple
   Constraints <http://arxiv.org/abs/1805.02408>`_.

.. [balazevic2019b] Balažević, I., Allen, C., & Hospedales, T. (2019). `Multi-relational Poincaré Graph
   Embeddings <http://arxiv.org/abs/1905.09791>`_.

.. [fuhr2018] Fuhr, N. (2018). `Some Common Mistakes In IR Evaluation, And How They Can Be Avoided
   <https://doi.org/10.1145/3190580.3190586>`_. SIGIR Forum, 51(3), 32–41.

.. [sakai2021] Sakai, T. (2021). `On Fuhr's Guideline for IR Evaluation
   <https://doi.org/10.1145/3451964.3451976>`_. SIGIR Forum, 54(1), 1-8.
